@@ -58,7 +58,7 @@ BOOT_SOURCE_TARGET_MAP = {
 BOOT_SOURCE_TARGET_MAP_REV = utils.revert_dictionary(BOOT_SOURCE_TARGET_MAP)
 
 BOOT_SOURCE_MODE_MAP = {
-    'BIOS': sys_cons.BOOT_SOURCE_MODE_BIOS,
+    'Legacy': sys_cons.BOOT_SOURCE_MODE_BIOS,
     'UEFI': sys_cons.BOOT_SOURCE_MODE_UEFI,
 }
 
@@ -82,3 +82,20 @@ PROCESSOR_ARCH_VALUE_MAP = {
 
 PROCESSOR_ARCH_VALUE_MAP_REV = (
     utils.revert_dictionary(PROCESSOR_ARCH_VALUE_MAP))
+
+HEALTH_STATE_VALUE_MAP = {
+    'Enabled': sys_cons.HEALTH_STATE_ENABLED,
+    'Disabled': sys_cons.HEALTH_STATE_DISABLED,
+}
+
+HEALTH_STATE_VALUE_MAP_REV = (
+    utils.revert_dictionary(HEALTH_STATE_VALUE_MAP))
+
+HEALTH_VALUE_MAP = {
+    'OK': sys_cons.HEALTH_OK,
+    'Warning': sys_cons.HEALTH_WARNING,
+    'Critical': sys_cons.HEALTH_CRITICAL
+}
+
+HEALTH_VALUE_MAP_REV = (
+    utils.revert_dictionary(HEALTH_VALUE_MAP))
